package com.chelvc.framework.group;

import java.util.Collection;
import java.util.Map;

import com.chelvc.framework.common.model.Caps;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 场景分组客户端
 *
 * @author Woody
 * @date 2024/12/5
 */
@FeignClient(value = "${group.store-server:group-store-server}")
public interface GroupClient {
    /**
     * 获取场景分组
     *
     * @param id    用户ID
     * @param scene 场景标识
     * @return 分组标识
     */
    @GetMapping("/user/{id}/group/{scene}")
    Caps getGroup(@PathVariable("id") Long id, @PathVariable("scene") String scene);

    /**
     * 批量获取场景分组
     *
     * @param id     用户ID
     * @param scenes 场景标识集合
     * @return 场景/分组映射表
     */
    @GetMapping("/user/{id}/groups")
    Map<String, Caps> getGroups(@PathVariable("id") Long id, @RequestParam("scenes") Collection<String> scenes);

    /**
     * 设置场景分组
     *
     * @param id    用户ID
     * @param scene 场景标识
     * @param group 分组标识
     */
    @PostMapping("/user/{id}/group/{scene}/{group}")
    void setGroup(@PathVariable("id") Long id, @PathVariable("scene") String scene, @PathVariable("group") Caps group);

    /**
     * 批量设置场景分组
     *
     * @param id     用户ID
     * @param groups 场景/分组映射表
     */
    @PostMapping("/user/{id}/groups")
    void setGroups(@PathVariable("id") Long id, @RequestBody Map<String, Caps> groups);
}
